#![doc = include_str!("../README.md")]
use proc_macro::TokenStream;
use syn::parse_macro_input;
use quote::quote;
use const_frac::frac::syn:: { TokenFrac, ClonedPath };

#[proc_macro]
pub fn frac(input: TokenStream) -> TokenStream {
    let result = parse_macro_input!(input as TokenFrac<ClonedPath>);

    quote! { #result }.into()
}
